@@ -9,7 +9,7 @@ class IntStringDict(UserDict):
             pass
         try:
             for k, v in self.data.items():
-                if v == key:
+                if v.lower() == key.lower():
                     return k
         except KeyError:
             pass
@@ -20,3 +20,9 @@ class IntStringDict(UserDict):
             self.data[key] = value
         elif type(key).__name__ == "str":
             self.data[value] = key
+
+
+def hex_to_rgb(hex_value):
+    hex_value = hex_value.lstrip("#")
+    color_value_list = list(int(hex_value[i : i + 2], 16) for i in (0, 2, 4))
+    return color_value_list
